@@ -25,7 +25,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
@@ -34,9 +34,10 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
-                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
-                            '-flto -fno-semantic-interposition -flto '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
+                            '-Werror=odr -Werror=lto-type-mismatch '
+                            '-Werror=strict-aliasing -flto '
+                            '-fno-semantic-interposition -flto '
                             '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
                             '-Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -68,7 +69,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' '--with-platlibdir=lib' "
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--enable-optimizations' "
+                "'--with-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
@@ -658,27 +659,29 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
-                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
-                    '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
-                    '-Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-fprofile-use -fprofile-correction -I./Include/internal '
-                    '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                    '-march=x86-64 -mtune=generic -Werror=odr '
+                    '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
+                    '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
-                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -fno-semantic-interposition '
-                   '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
-                   '-Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-fprofile-use -fprofile-correction -I./Include/internal '
-                   '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
+                   '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                   '-march=x86-64 -mtune=generic -Werror=odr '
+                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                   '-I./Include/internal -I. -I./Include '
+                   '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -686,15 +689,16 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
-                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
-                    '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
-                    '-Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-fprofile-use -fprofile-correction -I./Include/internal '
-                    '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
+                    '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                    '-march=x86-64 -mtune=generic -Werror=odr '
+                    '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
+                    '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -1020,7 +1024,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG',
+ 'OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1059,8 +1063,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                             '-march=x86-64 -mtune=generic -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto '
                              '-fno-semantic-interposition -flto '
@@ -1073,8 +1077,8 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare',
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -g -std=c11 -Wextra '
@@ -1084,16 +1088,16 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fvisibility=hidden -fprofile-use -fprofile-correction '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
-                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -fno-semantic-interposition '
-                   '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
-                   '-Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-fprofile-use -fprofile-correction -I./Include/internal '
-                   '-I. -I./Include -I/usr/include/ncursesw -fPIC '
-                   '-DPy_BUILD_CORE',
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                   '-march=x86-64 -mtune=generic -Werror=odr '
+                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                   '-I./Include/internal -I. -I./Include '
+                   '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
                     '-Werror=strict-aliasing -flto -fno-semantic-interposition '
@@ -1112,8 +1116,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                        '-march=x86-64 -mtune=generic -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
                         '-flto -fno-semantic-interposition -flto '
                         '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
